# -*- coding: utf-8 -*-

# System Imports
import os

# Imports
from .helpers import print_line
from .helpers import clear_window


def render_banner():

    with open(os.path.join(os.path.dirname(__file__), "assets", "banner.txt"), "r") as fh:
        banner = fh.read()
    print("")
    print("")
    print(banner)
    print("")
    print("")


def render_menu():
    print("    LEVEL OF THE GAME")
    print_line()
    print("")
    print("    1- Easy")
    print("    2- Hard")
    print("")
    print_line()
    print("")


def render_invalid_level():
    print_line()
    print("    Invalid option. Try again!")
    print_line()
    print("")
    print("")


def render_scoreboard(level, player_round, player_score):
    clear_window()
    render_banner()
    print("")
    print_line()
    print("")
    print("    Level: %s" % ("Easy" if level == "1" else "Hard"))
    print("    Round: %s" % (player_round))
    print("    Points Remaining: %s" % player_score)
    print("")
    print_line()


def render_placeholder(placeholder):
    print("")
    print("    Word: %s" % placeholder)


def render_hard_win_message(word):
    print("")
    print_line()
    print("")
    print("    >> THE PLAYER 2 GUESSED ALL THE LETTERS: %s" %
          ("".join(sorted(word))))


def render_game_over(player, word):
    if player == 1:
        print("")
        print_line()
        print("")
        print("    >> THE PLAYER 1 IS THE WINNER \O/")
        print("")
        print("    >> The word was: %s" % word)
        print("")
        print("    ## GAME OVER ##")
        print("")
    if player == 2:
        print("")
        print_line()
        print("")
        print("    >> THE PLAYER 2 IS THE WINNER \O/")
        print("")
        print("    ## GAME OVER ##")
        print("")



# -*- coding: utf-8 -*-

# Imports
from .helpers import find_occurrences
from .inquirer import ask_final_guess
from .renderer import render_game_over
from .renderer import render_hard_win_message


def generate_placeholder(db, word, letter):
    occurrences = find_occurrences(word, letter)
    for _ in occurrences:
        db.put_placeholder(letter)
        db.set_placeholders(sorted(db.get_placeholders()))
    return "".join(db.get_placeholders())


def check_round_state(db):
    if db.get_score() == 0:
        render_game_over(1, db.get_word())
        exit(0)
    if sorted(db.get_word()) == db.get_placeholders():
        render_hard_win_message(db.get_word())
        final_guess = ask_final_guess()
        if final_guess == db.get_word():
            render_game_over(2, db.get_word())
            exit(0)
        else:
            render_game_over(1, db.get_word())
            exit(0)



# -*- coding: utf-8 -*-


class Database:

    def __init__(self):
        self.__game_level = None
        self.__chosen_word = ""
        self.__chosen_letter = ""
        self.__placeholders = []
        self.__hunches = []
        self.__round = 0
        self.__score = 0

    def get_level(self):
        return self.__game_level

    def set_level(self, l):
        self.__game_level = l

    def get_word(self):
        return self.__chosen_word

    def set_word(self, w):
        self.__chosen_word = w

    def get_letter(self):
        return self.__chosen_letter

    def set_letter(self, l):
        self.__chosen_letter = l

    def get_placeholders(self):
        return self.__placeholders

    def set_placeholders(self, ph):
        self.__placeholders = ph

    def put_placeholder(self, l):
        self.__placeholders.append(l)

    def update_placeholder(self, i, l):
        self.__placeholders[i] = l

    def get_hunches(self):
        return self.__hunches

    def set_hunches(self, h):
        self.__hunches = h

    def add_hunch(self, h):
        self.__hunches.append(h)

    def get_round(self):
        return self.__round

    def increase_round(self):
        self.__round += 1

    def get_score(self):
        return self.__score

    def set_score(self):
        self.__score = len(
            self.__chosen_word) if self.__score == 0 else self.__score

    def deduct_score(self):
        self.__score -= 1



# -*- coding: utf-8 -*-

# Imports
from .engine import start_game
from .helpers import print_message

# Start the game
try:
    start_game(True)
# Catch exceptions
except Exception as e:
    print_message("An error has occurred during the game: %s" % e)
except KeyboardInterrupt:
    print("")
    print("\n    Game closed. See you later :)")
    print("")
    exit(0)
